# -*- coding: utf-8 -*-
# Пример основан на С++ Tutorial (С) 2006 Tim Sutton
# Портирование на Python: Martin Dobias, при участии Gary Sherman, изменения для FOSS4G2007
# Адаптация, перевод, изменения sim@gis-lab.info
# Лицензия GNU GPL 2

from PyQt4.QtCore import *
from PyQt4.QtGui import *
from qgis.core import *
from qgis.gui import *
import sys, os

# импорт виджета списка слоёв
from legend import Legend

# Импорт созданного интерфейса
from mainwindow_ui import Ui_MainWindow

# Считываем значение переменной окружения QGISHOME, которая должна указывать на каталог с
# установленным QGIS.
qgis_prefix = os.getenv( "QGISHOME" )

class MainWindow( QMainWindow, Ui_MainWindow ):
  def __init__( self ):
    QMainWindow.__init__( self )

    # Требуется Qt4 для инициализации пользовательского интерфейса
    self.setupUi( self )

    # Устанавливаем заголовок окна
    self.setWindowTitle( "QGIS Legend Demo" )

    # Создаем карту
    self.canvas = QgsMapCanvas()
    # Задаем цвет фона карты
    self.canvas.setCanvasColor( QColor( 200, 200, 255 ) )
    self.canvas.enableAntiAliasing( True )
    self.canvas.show()

    # Размещаем виджеты в окне
    self.layout = QVBoxLayout( self.frame )
    self.layout.addWidget( self.canvas )

    # Создаём и инициализируем легенду
    self.createLegendWidget()

    # Задаем действия для каждого из инструментов и соединяем их с соответсвующими методами
    self.connect( self.mpActionAddLayer, SIGNAL( "triggered()" ), self.addLayer );
    self.connect( self.mpActionZoomIn, SIGNAL( "triggered()" ), self.zoomIn );
    self.connect( self.mpActionZoomOut, SIGNAL( "triggered()" ), self.zoomOut );
    self.connect( self.mpActionPan, SIGNAL( "triggered()" ), self.pan );
    self.connect( self.mpActionZoomFullExtent, SIGNAL( "triggered()" ), self.zoomFull );

    # Создаем панель инструментов
    self.toolbar = self.addToolBar( "Map" );
    # Добавляем действия на панель инструментов
    self.toolbar.addAction( self.mpActionAddLayer );
    self.toolbar.addAction( self.mpActionZoomIn );
    self.toolbar.addAction( self.mpActionZoomOut );
    self.toolbar.addAction( self.mpActionPan );
    self.toolbar.addAction( self.mpActionZoomFullExtent );

    # Создаем инструменты карты
    self.toolPan = QgsMapToolPan( self.canvas )
    self.toolPan.setAction( self.mpActionPan )
    self.toolZoomIn = QgsMapToolZoom( self.canvas, False ) # false = уменьшить
    self.toolZoomIn.setAction( self.mpActionZoomIn )
    self.toolZoomOut = QgsMapToolZoom( self.canvas, True ) # true = увеличить
    self.toolZoomOut.setAction( self.mpActionZoomOut )

  def createLegendWidget( self ):
    self.legend = Legend( self )
    self.legend.setCanvas( self.canvas )
    self.legend.setObjectName( "theMapLegend" )

    self.LegendDock = QDockWidget( "Layers", self )
    self.LegendDock.setObjectName( "legend" )
    self.LegendDock.setAllowedAreas( Qt.LeftDockWidgetArea | Qt.RightDockWidgetArea )
    self.LegendDock.setWidget( self.legend )
    self.LegendDock.setContentsMargins ( 9, 9, 9, 9 )
    self.addDockWidget( Qt.LeftDockWidgetArea, self.LegendDock )

  # Установить инструмент увеличения
  def zoomIn( self ):
    self.canvas.setMapTool( self.toolZoomIn )

  # Установить инструмент уменьшения
  def zoomOut( self ):
    self.canvas.setMapTool( self.toolZoomOut )

  # Установить инструмент для перемещения
  def pan( self ):
    self.canvas.setMapTool( self.toolPan )

  # Установить инструмент показа карты полностью
  def zoomFull( self ):
    self.canvas.zoomToFullExtent()

  # Добавить OGR-слой
  def addLayer( self ):
    filtering = QString( "Shapefiles (*.shp)" )
    encode = QString( "System" )
    fileDialog = QgsEncodingFileDialog( self, "Open shapefile", ".", QString( filtering ), encode )
    fileDialog.setFileMode( QFileDialog.ExistingFiles )
    fileDialog.setAcceptMode( QFileDialog.AcceptOpen )

    if not fileDialog.exec_() == QDialog.Accepted:
      return

    files = fileDialog.selectedFiles()

    for f in files:
      layerPath = unicode( f )
      layer = QgsVectorLayer( layerPath, QFileInfo( layerPath ).baseName(), "ogr" )
      if not layer.isValid():
        print "Layer %1 is not valid" % layerPath
        continue
      QgsMapLayerRegistry.instance().addMapLayer( layer )

    self.canvas.zoomToFullExtent()

def main( app ):

  # Инициализация библиотек QGIS
  QgsApplication.setPrefixPath( qgis_prefix, True )
  QgsApplication.initQgis()

  # Создание приложения
  wnd = MainWindow()
  wnd.show()

  # Запуск!
  retval = app.exec_()

  # Выход
  QgsApplication.exitQgis()
  sys.exit( retval )


if __name__ == "__main__":

  # Создать приложение Qt
  app = QApplication( sys.argv )

  main( app )
